@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004, Nate Nielsen
+ * Copyright (c) 2004, Stefan Walter
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without 
@@ -32,7 +32,7 @@
  * 
  *
  * CONTRIBUTORS
- *  Nate Nielsen <nielsen@memberwebs.com>
+ *  Stef Walter <stef@memberwebs.com>
  */ 
 
 #include <sys/types.h>
@@ -177,7 +177,7 @@ int main(int argc, char* argv[])
 
         /* Print version number */
         case 'v':
-            printf("clamsmtpd (version %s)\n", VERSION);
+            printf("proxsmtpd (version %s)\n", VERSION);
             printf("          (config: %s)\n", DEFAULT_CONFIG);
             exit(0);
             break;
@@ -437,7 +437,7 @@ cleanup:
 
 static int process_file_command(spctx_t* sp)
 {
-    pid_t pid;
+    pid_t pid = 0;
     int ret = 0, status, r;
     struct timeval timeout;
         
